@@ -5,6 +5,7 @@ from gql.transport.requests import RequestsHTTPTransport
 import urllib3; urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 import pandas as pd
 from polity import static
+from polity import schemas
 from polity.static import (
     DATASET_NAME_DESC_QUERY,
     COMPANY_CIK_NAME_QUERY,
@@ -80,8 +81,8 @@ class Client():
             if data['income']: data['income'] = to_df(data['income'])
             if data['balance']: data['balance'] = to_df(data['balance']) 
             if data['cash']: data['cash'] = to_df(data['cash'])
-
-        return data
+            if data['equity']: data['equity'] = to_df(data['equity'])
+        return schemas.company(data)
 
     def companies(self):
         static.companies()
